@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Moose;
 use Moose::Util::TypeConstraints qw(enum);
@@ -117,9 +117,9 @@ sub add_badges {
         } elsif ($badge eq 'gitlab_cover') {
             push @badges, "[![coverage report](https://$base_url/$user_name/$repository_name/badges/master/coverage.svg)]($repository/$user_name/$repository_name/commits/master)";
         } elsif ($badge eq 'docker_automated') {
-            push @badges, "[![Docker Automated Build](https://img.shields.io/docker/automated/$user_name/$repository_name.svg)](https://github.com/$user_name/$repository_name)";
+            push @badges, "[![Docker Automated Build](https://img.shields.io/docker/automated/\L$user_name/$repository_name\E.svg)](https://github.com/\L$user_name/$repository_name\E)";
         } elsif ($badge eq 'docker_build') {
-            push @badges, "[![Docker Build Status](https://img.shields.io/docker/build/$user_name/$repository_name.svg)](https://hub.docker.com/r/$user_name/$repository_name/)";
+            push @badges, "[![Docker Build Status](https://img.shields.io/docker/build/\L$user_name/$repository_name\E.svg)](https://hub.docker.com/r/\L$user_name/$repository_name\E/)";
         }
     }
 
